self.__BUILD_MANIFEST=function(s,e,i,n,p,c,t,a,l,u,d,f,r,b,k,h,j,g,o,_,m,E,O,A,B,L,D,T,C){return{__rewrites:{beforeFiles:[],afterFiles:[{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_/datasets",destination:j},{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_",destination:j}],fallback:[]},"/":[s,i,"static/chunks/pages/index-242a33f6b14ebd84.js"],"/_error":["static/chunks/pages/_error-235304e5badb19eb.js"],"/datasets":[s,e,n,p,A,"static/chunks/pages/datasets-8c1f895b0c7ac523.js"],"/datasets/[...slug]":[g,"static/chunks/8a28b14e-b845f39223877713.js",s,e,n,u,d,r,b,o,B,"static/chunks/17-6f5e28da6ea3bc27.js",p,t,a,k,_,L,A,"static/chunks/pages/datasets/[...slug]-13a0106fe9628467.js"],"/manage":[s,e,n,i,p,c,a,"static/chunks/pages/manage-041c61939f78152a.js"],"/pipeline-runs":[s,e,n,i,p,c,a,m,"static/chunks/pages/pipeline-runs-e1fd16de7552cd27.js"],"/pipelines":[s,e,n,i,p,c,"static/chunks/pages/pipelines-356fda7082ef5e4d.js"],"/pipelines/[pipeline]":["static/chunks/pages/pipelines/[pipeline]-0c6dc5356df3d124.js"],"/pipelines/[pipeline]/edit":[g,s,e,n,u,f,d,r,b,E,o,O,D,B,"static/chunks/1869-76da4d07a68399ef.js",i,p,c,t,a,k,h,_,L,"static/chunks/pages/pipelines/[pipeline]/edit-4b06dc7ffc19be1d.js"],"/pipelines/[pipeline]/logs":[s,e,n,f,O,T,i,p,c,t,l,a,"static/chunks/pages/pipelines/[pipeline]/logs-87eb1b8fc5e355fc.js"],"/pipelines/[pipeline]/monitors":[s,e,n,u,b,i,p,c,t,l,C,"static/chunks/pages/pipelines/[pipeline]/monitors-00ea20e16b43e3c0.js"],"/pipelines/[pipeline]/monitors/block-runs":[s,e,n,u,b,i,p,c,t,l,a,C,"static/chunks/pages/pipelines/[pipeline]/monitors/block-runs-acf1f7cac4768e76.js"],"/pipelines/[pipeline]/monitors/block-runtime":[g,s,e,n,u,b,"static/chunks/9832-c8b8970bb522f302.js",i,p,c,t,l,a,_,"static/chunks/pages/pipelines/[pipeline]/monitors/block-runtime-f197ac539383dd10.js"],"/pipelines/[pipeline]/runs":[s,e,n,f,d,E,i,p,c,t,l,a,h,m,"static/chunks/pages/pipelines/[pipeline]/runs-88612f6dc04976fb.js"],"/pipelines/[pipeline]/runs/[run]":[s,e,n,u,f,d,r,o,i,p,c,t,l,k,h,"static/chunks/pages/pipelines/[pipeline]/runs/[run]-d1fa65d25622b03a.js"],"/pipelines/[pipeline]/syncs":[s,e,n,i,p,c,t,l,"static/chunks/pages/pipelines/[pipeline]/syncs-792b4ae3694c5fc0.js"],"/pipelines/[pipeline]/triggers":[s,e,n,u,f,d,r,i,p,c,t,l,k,h,"static/chunks/pages/pipelines/[pipeline]/triggers-c6c57485603f2f9d.js"],"/pipelines/[pipeline]/triggers/[...slug]":[s,e,n,u,f,d,r,E,T,i,p,c,t,l,a,k,h,m,"static/chunks/pages/pipelines/[pipeline]/triggers/[...slug]-75beeae47e88d25b.js"],"/terminal":[s,e,O,D,i,"static/chunks/pages/terminal-c248ec9e65efd81b.js"],sortedPages:["/","/_app","/_error",j,"/datasets/[...slug]","/manage","/pipeline-runs","/pipelines","/pipelines/[pipeline]","/pipelines/[pipeline]/edit","/pipelines/[pipeline]/logs","/pipelines/[pipeline]/monitors","/pipelines/[pipeline]/monitors/block-runs","/pipelines/[pipeline]/monitors/block-runtime","/pipelines/[pipeline]/runs","/pipelines/[pipeline]/runs/[run]","/pipelines/[pipeline]/syncs","/pipelines/[pipeline]/triggers","/pipelines/[pipeline]/triggers/[...slug]","/terminal"]}}("static/chunks/4259-f723eee7c5c19f8e.js","static/chunks/2212-f7752030be6ab268.js","static/chunks/1374-aba9a59280f0ef4f.js","static/chunks/7689-30032583a188b1a4.js","static/chunks/5763-0d4713d3c0348cdd.js","static/chunks/6792-30e5e6ee58f37731.js","static/chunks/1273-34cac2dc95a1dfc7.js","static/chunks/9898-98e596a737fbb34b.js","static/chunks/8965-4a7d71fcc6aefa04.js","static/chunks/6674-63776cbaecd7c1d9.js","static/chunks/1774-aa51ef1da7217ff9.js","static/chunks/4804-01a10103ebe26ca8.js","static/chunks/3668-3b07d0117a5db904.js","static/chunks/2714-1e79e9f2e998b544.js","static/chunks/2151-11e7139c32bb7ab4.js","static/chunks/5703-25e331a4ef2d64be.js","/datasets","static/chunks/29107295-989a0767a635d9d5.js","static/chunks/2125-d859c4773f5f76a8.js","static/chunks/3461-64870781b97c10bd.js","static/chunks/4846-224cc7c8fc82fa51.js","static/chunks/7619-11107d4d093f5d51.js","static/chunks/9565-28e1c30511c95c2d.js","static/chunks/3887-13f5cc240b3acfc2.js","static/chunks/5650-7bd2f076f244e576.js","static/chunks/9223-296d89ed2dd314a4.js","static/chunks/6085-692d2f784c0504f2.js","static/chunks/4495-aaa900f908a8a255.js","static/chunks/7400-a578d543bd286bdb.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();